@@ -298,6 +298,11 @@ class MyWhatify:
         logging.info('deleting task_id: ' + str(task_id))
         my_toolkit.Task.delete(task_id)
 
+    @classmethod
+    def delete_prediction(cls, pred_id):
+        logging.info('deleting pred_id: ' + str(pred_id))
+        my_toolkit.Prediction.delete(pred_id)
+
     # def delete_user(cls, email=None, password=None, delete_user_id=None):
     #     with allure.step('Marking user email ' + str(email) + ' or user_id:' + str(delete_user_id) + ' as Deleted in the DB with API'):
     #         logging.info('deleting user email: ' + str(email))
